@@ -1,4 +1,4 @@
-/* $Id: acconfig.h,v 1.15 2001/04/02 05:36:08 astyanax Exp $ */
+/* $Id: acconfig.h,v 1.15.2.1 2002/01/12 23:17:15 astyanax Exp $ */
 
 /* Define this if you have the wresize function in your ncurses-type library */
 #undef HAVE_WRESIZE
@@ -51,3 +51,6 @@
 /* Define this to disable any and all text wrapping */
 #undef DISABLE_WRAPPING
 
+/* Define this to disable wrapping as root by default */
+#undef DISABLE_ROOTWRAP
+
