@@ -1,4 +1,4 @@
-/* $Id: files.c,v 1.105.2.5 2001/10/24 11:42:21 astyanax Exp $ */
+/* $Id: files.c,v 1.105.2.8 2002/03/26 12:58:11 astyanax Exp $ */
 /**************************************************************************
  *   files.c                                                              *
  *                                                                        *
@@ -180,13 +180,21 @@ int read_file(int fd, char *filename)
 	num_lines++;
 	buf[0] = 0;
     }
-    /* Did we even GET a file? */
+
+    /* Did we even GET a file if we don't already have one? */
     if (totsize == 0 || fileptr == NULL) {
 	new_file();
 	statusbar(_("Read %d lines"), num_lines);
 	return 1;
     }
 
+   /* Did we try to insert a file of 0 bytes? */
+    if (num_lines == 0)
+    {
+        statusbar(_("Read %d lines"), 0);
+        return 1;
+    }
+
     if (current != NULL) {
 	fileptr->next = current;
 	current->prev = fileptr;
@@ -1077,7 +1085,7 @@ void free_charptrarray(char **array, int len)
 {
     int i;
 
-    for (i = 0; i < len - 1; i++)
+    for (i = 0; i < len; i++)
 	free(array[i]);
     free(array);
 }
@@ -1116,7 +1124,10 @@ void striponedir(char *foo)
     if (tmp != foo)
 	*tmp = 0;
     else
+    { /* SPK may need to make a 'default' path here */
+        if (*tmp != '/') *(tmp) = '.';
 	*(tmp+1) = 0;
+    }
 
     return;
 }
@@ -1245,6 +1256,17 @@ char *do_browser(char *inpath)
 	    else
 		path = mallocstrcpy(path, filelist[selected]);
 
+	    /* SPK for '.' path, get the current path via getcwd */
+	    if (!strcmp(path, "./..")) {
+		free(path);
+		path = getcwd(NULL, 0);
+		striponedir(path);		    
+		align(&path);
+		free_charptrarray(filelist, numents);
+		free(foo);
+		return do_browser(path);
+	    }
+
 	    st = filestat(path);
 	    if (S_ISDIR(st.st_mode)) {
 		if (opendir(path) == NULL) {
@@ -1264,6 +1286,8 @@ char *do_browser(char *inpath)
 		}
 
 		/* Start over again with the new path value */
+		free_charptrarray(filelist, numents);
+		free(foo);
 		return do_browser(path);
 	    } else {
 		retval = path;
