@@ -1,4 +1,4 @@
-/* $Id: utils.c,v 1.21.2.4 2001/10/24 11:42:22 astyanax Exp $ */
+/* $Id: utils.c,v 1.21.2.5 2002/02/28 00:48:47 astyanax Exp $ */
 /**************************************************************************
  *   utils.c                                                              *
  *                                                                        *
@@ -50,7 +50,7 @@ void lowercase(char *src)
 
 /* This is now mutt's version (called mutt_stristr) because it doesn't
    use memory allocation to do a simple search (yuck). */
-char *strcasestr(char *haystack, char *needle)
+char *stristr(char *haystack, char *needle)
 {
     const char *p, *q;
 
@@ -83,7 +83,7 @@ char *strstrwrapper(char *haystack, char *needle)
     if (ISSET(CASE_SENSITIVE))
 	return strstr(haystack, needle);
     else
-	return strcasestr(haystack, needle);
+	return stristr(haystack, needle);
 }
 
 /* Thanks BG, many ppl have been asking for this... */
