@@ -1,4 +1,4 @@
-/* $Id: winio.c,v 1.85.2.6 2002/01/07 14:41:15 astyanax Exp $ */
+/* $Id: winio.c,v 1.85.2.9 2002/03/16 01:19:31 astyanax Exp $ */
 /**************************************************************************
  *   winio.c                                                              *
  *                                                                        *
@@ -303,16 +303,17 @@ int nanogetstr(int allowtabs, char *buf, char *def, shortcut s[], int slen,
 #endif
 		break;
 	case KEY_HOME:
+	case NANO_HOME_KEY:
 	    x = x_left;
 	    nanoget_repaint(buf, inputbuf, x);
 	    break;
 	case KEY_END:
+	case NANO_END_KEY:
 	    x = x_left + strlen(inputbuf);
 	    nanoget_repaint(buf, inputbuf, x);
 	    break;
 	case KEY_RIGHT:
 	case NANO_FORWARD_KEY:
-
 	    if (x < xend)
 		x++;
 	    wmove(bottomwin, 0, x);
@@ -508,15 +509,17 @@ void titlebar(char *path)
     reset_cursor();
 }
 
-void onekey(char *keystroke, char *desc)
+void onekey(char *keystroke, char *desc, int len)
 {
-    char description[80];
+    int i;
 
-    snprintf(description, 12, " %-10s", desc);
     wattron(bottomwin, A_REVERSE);
     waddstr(bottomwin, keystroke);
     wattroff(bottomwin, A_REVERSE);
-    waddstr(bottomwin, description);
+    waddch(bottomwin, ' ');
+    waddnstr(bottomwin, desc, len - 3);
+    for (i = strlen(desc); i < len - 3; i++)
+	waddch(bottomwin, ' ');
 }
 
 void clear_bottomwin(void)
@@ -530,32 +533,23 @@ void clear_bottomwin(void)
 
 void bottombars(shortcut s[], int slen)
 {
-    int i, j, k;
+    int i;
     char keystr[10];
 
     if (ISSET(NO_HELP))
 	return;
 
-    /* Determine how many extra spaces are needed to fill the bottom of the screen */
-    k = COLS / 6 - 13;
-
     clear_bottomwin();
     wmove(bottomwin, 1, 0);
     for (i = 0; i <= slen - 1; i += 2) {
 	snprintf(keystr, 10, "^%c", s[i].val + 64);
-	onekey(keystr, s[i].desc);
-
-	for (j = 0; j < k; j++)
-	    waddch(bottomwin, ' ');
+	onekey(keystr, s[i].desc, COLS / 6);
     }
 
     wmove(bottomwin, 2, 0);
     for (i = 1; i <= slen - 1; i += 2) {
 	snprintf(keystr, 10, "^%c", s[i].val + 64);
-	onekey(keystr, s[i].desc);
-
-	for (j = 0; j < k; j++)
-	    waddch(bottomwin, ' ');
+	onekey(keystr, s[i].desc, COLS / 6);
     }
 
     wrefresh(bottomwin);
@@ -1048,18 +1042,18 @@ int do_yesno(int all, int leavecursor, char *msg, ...)
 	wmove(bottomwin, 1, 0);
 
 	snprintf(shortstr, 3, " %c", yesstr[0]);
-	onekey(shortstr, _("Yes"));
+	onekey(shortstr, _("Yes"), 16);
 
 	if (all) {
 	    snprintf(shortstr, 3, " %c", allstr[0]);
-	    onekey(shortstr, _("All"));
+	    onekey(shortstr, _("All"), 16);
 	}
 	wmove(bottomwin, 2, 0);
 
 	snprintf(shortstr, 3, " %c", nostr[0]);
-	onekey(shortstr, _("No"));
+	onekey(shortstr, _("No"), 16);
 
-	onekey("^C", _("Cancel"));
+	onekey("^C", _("Cancel"), 16);
     }
     va_start(ap, msg);
     vsnprintf(foo, 132, msg, ap);
@@ -1407,7 +1401,7 @@ void do_replace_highlight(int highlight_flag, char *word)
 }
 
 #ifdef NANO_EXTRA
-#define CREDIT_LEN 48
+#define CREDIT_LEN 52
 void do_credits(void)
 {
     int i, j = 0, k, place = 0, start_x;
@@ -1418,7 +1412,7 @@ void do_credits(void)
     char *brought = _("Brought to you by:");
     char *specialthx = _("Special thanks to:");
     char *fsf = _("The Free Software Foundation");
-    char *ncurses = _("Pavel Curtis, Zeyd Ben-Halim and Eric S. Raymond for ncurses");
+    char *ncurses = _("For ncurses:");
     char *anyonelse = _("and anyone else we forgot...");
     char *thankyou = _("Thank you for using nano!\n");
 
@@ -1458,6 +1452,10 @@ void do_credits(void)
 			fsf,
 			"Linus Torvalds",
 			ncurses,
+			"Thomas Dickey",
+			"Pavel Curtis",
+			"Zeyd Ben-Halim",
+			"Eric S. Raymond",
 			anyonelse,
 			thankyou,
 			"", "", "", "",
